"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LoggerConfig = void 0;
const lodash_1 = require("lodash");
const configs = require("./predefined-logger");
const type_guards_1 = require("../type-guards");
const logger_context_config_1 = require("./logger-context.config");
const defaultLogFieldNames = {
    context: 'context',
    labels: 'labels',
    trace: 'trace',
};
class LoggerConfig {
    constructor(config = {}) {
        this.context = logger_context_config_1.loggerContextConfig;
        this.labels = {};
        this.loggerOptions = {};
        this.logFieldNames = defaultLogFieldNames;
        let configToMerge = {};
        if ((0, type_guards_1.isPredefinedLogger)(config)) {
            configToMerge = configs[config];
        }
        else if ((0, type_guards_1.isCustomLogger)(config)) {
            const defaultValues = config.base
                ? configs[config.base]
                : {};
            configToMerge = (0, lodash_1.merge)(defaultValues, config);
        }
        (0, lodash_1.merge)(this, configToMerge);
    }
    getFieldNameContext() {
        return this.logFieldNames.context;
    }
    getFieldNameLabels() {
        return this.logFieldNames.labels;
    }
    getFieldNameTrace() {
        return this.logFieldNames.trace;
    }
}
exports.LoggerConfig = LoggerConfig;
